Date: 08 16, 2001 8:25:26 AM

# Text File Info

## Function

The Text File Info dialog displays information about a text file.

## Accessing

The Text File Info dialog can be displayed from several places within VisualText. It can be accessed from the main Tools Menu, the Text Tab Popup Menu under Tools, and from the Tools submenu in the Text File Popup Menu.

## Text File Info Display

The Text File Info dialog provides the location of the selected file, creation and modification dates, line count, word count, character count, and file size.